(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     46514,       1119]
NotebookOptionsPosition[     43446,       1068]
NotebookOutlinePosition[     44021,       1089]
CellTagsIndexPosition[     43978,       1086]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 20 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}, {
   3.890973965108789*^9, 3.8909739653874283`*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b05a49bb-672b-4e08-bf6c-4aa2718cba0d"],

Cell["Chapter 9, Section 9.9, Figure 9.35", "Section",ExpressionUUID->"0cb2454b-441b-4009-ba28-e4a0e17b409a"],

Cell[TextData[{
 "The functions defined here are those already used in, for example, ",
 StyleBox["Fig.8.1\[Dash]8.3.nb",
  FontWeight->"Bold"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.88943980058386*^9, 3.8894398037633467`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"40d5ca2b-c629-4b78-a3ed-63e435c2e1fd"],

Cell["\<\
We start by defining the radius as a function of semi-major axis, \
eccentricity and true anomaly.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"8160fe4d-b57a-47e3-95f2-b43828d07d73"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"r", "[", 
    RowBox[{"a_", ",", "e_", ",", "f_"}], "]"}], ":=", 
   RowBox[{"a", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"e", "^", "2"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"e", " ", 
        RowBox[{"Cos", "[", "f", "]"}]}]}], ")"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.889439814386648*^9, 3.889439814389461*^9}, {
  3.889441722402063*^9, 3.889441725492279*^9}, {3.8894417895126133`*^9, 
  3.8894417905466146`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"644d4524-6566-4ab3-afda-e28fb3c69d79"],

Cell[TextData[{
 "Now we define a function ",
 StyleBox["ksolve", "Input"],
 " that solves Kepler's equation to find the eccentric anomaly for a given \
value of the mean anomaly and eccentricity."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8894419687621403`*^9, 3.889441974566674*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"eae70547-4385-46fb-833d-2a11a349b9db"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ksolve", "[", 
    RowBox[{"ma_", ",", " ", "e_"}], "]"}], " ", ":=", " ", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"ea", " ", "-", " ", 
       RowBox[{"e", " ", 
        RowBox[{"Sin", "[", "ea", "]"}]}]}], " ", "==", " ", "ma"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"ea", ",", "ma"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.889439826433874*^9, 3.889439826437006*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"0e268aeb-cee9-4606-b4c0-5b42419b815d"],

Cell[TextData[{
 "The function ",
 StyleBox["position", "Input"],
 " calculates the ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and ",
 StyleBox["y",
  FontSlant->"Italic"],
 " coordinates of an object for a particular value of the mean anomaly."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"d30a51c2-eccf-41f1-9b89-f4d92bc8aa87"],

Cell[BoxData[
 RowBox[{
  RowBox[{"position", "[", 
   RowBox[{"ma_", ",", "a_", ",", "e_"}], "]"}], ":=", "\[IndentingNewLine]", 
  
  RowBox[{"(", 
   RowBox[{
    RowBox[{"eca", "=", 
     RowBox[{"ea", " ", "/.", " ", 
      RowBox[{"ksolve", "[", 
       RowBox[{"ma", ",", "e"}], "]"}]}]}], ";", 
    RowBox[{"x", "=", 
     RowBox[{"N", "[", 
      RowBox[{"a", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Cos", "[", "eca", "]"}], "-", "e"}], ")"}]}], "]"}]}], ";", 
    " ", 
    RowBox[{"y", "=", 
     RowBox[{"N", "[", 
      RowBox[{"a", " ", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", "-", 
         RowBox[{"e", "^", "2"}]}], "]"}], " ", 
       RowBox[{"Sin", "[", "eca", "]"}]}], "]"}]}], ";", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.889439839768878*^9, 3.8894398397717667`*^9}, {
  3.889439992193252*^9, 3.8894400122326803`*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"2589c640-3b19-4c90-b800-909f8d6e77ff"],

Cell[TextData[{
 "We set the list of points, ",
 StyleBox["rotlist", "Input"],
 ", to be empty."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"32930df0-f043-41bf-8bbf-bc799e8987d3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rotlist", "=", 
   RowBox[{"{", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.889439874955802*^9, 3.8894398749587727`*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"92e26b0a-de9f-4d4a-a051-03be73155876"],

Cell["\<\
Define the resonance (3:2), the semi-major axis (unity) and the eccentricity \
(0.2488).\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c75a3481-4524-4761-b2ac-3ae27b47cd8c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"p", "=", 
   RowBox[{"3", "/", "2"}]}], ";", " ", 
  RowBox[{"a", "=", "1.0"}], ";", " ", 
  RowBox[{"e", "=", "0.2488"}], ";"}]], "Input",
 CellChangeTimes->{{3.8894398871833878`*^9, 3.889439887186493*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"76b66bad-ed3b-47c0-928b-697d83a92631"],

Cell["Create the list of points that make up the orbit.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"38c9d84c-d097-46f1-91d8-54b0f37f2041"],

Cell[BoxData[
 RowBox[{"Do", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"posvec", "=", 
      RowBox[{"position", "[", 
       RowBox[{"t", ",", "a", ",", "e"}], "]"}]}], ";", 
     RowBox[{"f", "=", 
      RowBox[{"N", "[", 
       RowBox[{"ArcTan", "[", 
        RowBox[{
         RowBox[{"posvec", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{"posvec", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}]}], ";", 
     RowBox[{"rad", "=", 
      RowBox[{"N", "[", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"posvec", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "^", "2"}], "+", 
         RowBox[{
          RowBox[{"posvec", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "^", "2"}]}], "]"}], "]"}]}], ";", 
     
     RowBox[{"\[Theta]", "=", 
      RowBox[{"p", "*", "t"}]}], ";", 
     RowBox[{"\[Psi]", "=", 
      RowBox[{"\[Theta]", "-", "f"}]}], ";", 
     RowBox[{"blip", "=", 
      RowBox[{"N", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"rad", "*", 
          RowBox[{"Cos", "[", "\[Psi]", "]"}]}], ",", 
         RowBox[{"rad", "*", 
          RowBox[{"Sin", "[", "\[Psi]", "]"}]}]}], "}"}], "]"}]}], ";", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"rotlist", ",", "blip"}], "]"}], ";"}], ")"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"4", "Pi"}], ",", 
     RowBox[{"Pi", "/", "50"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.889439906126548*^9, 3.8894399061294928`*^9}, {
  3.8894400278484488`*^9, 3.88944006114719*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"09a11beb-f2e6-40a3-b80b-408b892224da"],

Cell["Plot the points as the path in the rotating frame.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"de72363e-dbf8-40a3-a918-8e3024779d8e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pa", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"rotlist", ",", 
    RowBox[{"AspectRatio", "->", "Automatic"}], ",", 
    RowBox[{"Joined", "->", "True"}], ",", 
    RowBox[{"Axes", "->", "None"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8894399317903357`*^9, 3.889439940893869*^9}, 
   3.889440067717558*^9},
 CellLabel->"In[7]:=",ExpressionUUID->"ec2fd0c9-b23f-440f-99df-f0a4bd569f79"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxVl3lU1HUUxUGtcCH1uCRYmU4qGrge0hJ8IibmvuQCJoJg4lIkqAmWaG4E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      "]]}}, {{}, {}}},
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-1.0100757741834467`, 1.0100757741834465`}, {-1.2488, 1.2488}},
  
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8894400933354597`*^9, 3.8894417541038313`*^9, 
  3.889441792587282*^9, 3.889462693976121*^9, 3.889462764248226*^9, 
  3.89101738200572*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"6905be7b-6df0-4d31-b903-0fcef784d6c9"]
}, Open  ]],

Cell["\<\
Plot the points as individual points along the path in the rotating frame \
taking every other point.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{
  3.889439447802987*^9, {3.889462738418848*^9, 3.889462743502709*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"7cee5d2c-70e4-4cfe-b18f-47bd230f3fb5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pb", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{
    RowBox[{"Take", "[", 
     RowBox[{"rotlist", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{"Length", "[", "rotlist", "]"}], ",", "2"}], "}"}]}], "]"}], 
    ",", 
    RowBox[{"PlotStyle", "->", 
     RowBox[{"PointSize", "[", "0.02", "]"}]}], ",", 
    RowBox[{"AspectRatio", "->", "Automatic"}], ",", " ", 
    RowBox[{"Axes", "->", "None"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.889439953601766*^9, 3.889439971462893*^9}, 
   3.889440074827236*^9},
 CellLabel->"In[8]:=",ExpressionUUID->"7ce62d0c-660b-4804-aeac-de83fe5ad097"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVlWtMk3cUxgtx8QJGE0UBE5mghqhM3UJwWjzzEkviBVEBa6aZCFl1Mw0W
MYMl6vbFgMVYFOIHb0ERRLlYESaEMyUMGUXphngJQweiLW2hwCbUjt16nveD
JA0f3rz//znP83ued16Kfluav0qlSvvv9///c4uCz3ZMtpEKf6d3HxqbMN9G
4UEXz9ccPcPVc789bk+3UfXVbebCtUWcodEUxg/ZqL0v8Xz581Kel2dSTb9g
p1WBDeWa0Ru8/0/nB2fT++lH54WAyzfL+GfTudDcFAf5uTVjWrrK5s/XRT5P
dZLfnLbOxlgTN8dYdY79Lnrdnx31NMREbxakLlu6d4DyTYvKfr1VSTl/7Axp
XzFIzZlf92TYmbwJdfuOdw/SsreOpvWqFgovKvlmyYduWplRG7/ihpUyXkb6
dyx005d7b3ssaU+owmOwNI8OUk9hpL7I+BvdPbXrRfvHg6Q92HYt+5/fyZ7o
dyb6rYuOVowbEuL6qDaoN+DTWCcVGGvur861UXDPyLvYif2UNMF/2qEqB3md
nmF78hv66IvR8agrA1QwY2vtnJhX1Hp3se5RsZuWJv3lvV35kjT67/c9tgxR
UpdHayh5RjmpxbSrbpg6H+aWntZZKSm4ID3iqxHK0eqifym8R44g8yVr5wgN
BEb8tG5Kgdrcb6gO8o5Qljxn5flTeZ+V99VyPp/E+bifN+D+PJmPH2I+P5dv
fo7E/CGyHydjvzrZn5X9X4g+nAd9GkQ/3gr9KkVfVvQ1iP58EPrDH14Df+Af
R8G/k+Iv98Bfu/jPevgPPniqQ/gAPzwGflqFL94Nvg4If1wF/sKFT74eIHwe
Fn559Wvh947wzf7FwrdJ+OeuGcI/8sHlxya5A3vNauSDs2f6npPy/nZ5n5AP
PiXnE/LBf8v9pMzX5fLNRxbMXyvzUxX2c4b69qMm7B/m9O3PyAerRR9W9CsX
/dgDfXeIvqzo/4noz0fgD4k/bIZ/HeIf/wB/kQ/uhf8nxH9uBR/fCR8cBn4S
hB+2Sz54pfDFyAdbhD+OAZ/rhU/eCH6RD74HvpOFb94E/p3CPyeU7dnsjWus
Rz44FPlx4Xn7+/niaOTPiPOjkM843J+D/D7CfN3I92eYfzbyr8V+TegHI/bv
Rn/kQ5/r6BcD9KtB/7RA30z0UyL0X4j+mgR/xtFvavhnRP+Nw99X6MesfPH/
AfpTL/ngCvSrNUT4aUP/LgdfOvTzkgHhLwL9HS/9TZno9y3S71SD/p8l/U/K
92GqfB9I+X5IPhrr/wXgaIMx
     "]]}, {{}, {}}},
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-1.0094795307504947`, 1.0094795307504945`}, {-1.2488, 1.2488}},
  
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.812012959156595*^9, 3.889433464359213*^9, 3.889433518818522*^9, 
   3.8894392803320227`*^9, {3.8894394735953617`*^9, 3.889439493455853*^9}, 
   3.889439550783738*^9, 3.889439643153268*^9, 3.889439756825055*^9, 
   3.889440093358672*^9, 3.889441754129518*^9, 3.889441792612568*^9, 
   3.889462694040895*^9, 3.889462764296818*^9, 3.891017382140436*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"cb762470-78ea-4307-a0d1-2619f55c4899"]
}, Open  ]],

Cell["Show both plots together.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"29eaf0ba-9c9e-4b23-9c1a-da2f0185d3cd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"basic", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"pa", ",", "pb"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.889440144190399*^9, 3.8894401441934233`*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"7656016e-091c-4f12-84a2-322ebe166d2a"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxVl3lU1HUUxUGtcCH1uCRYmU4qGrge0hJ8IibmvuQCJoJg4lIkqAmWaG4E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       "]]}}, {{}, {}}}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVlWtMk3cUxgtx8QJGE0UBE5mghqhM3UJwWjzzEkviBVEBa6aZCFl1Mw0W
MYMl6vbFgMVYFOIHb0ERRLlYESaEMyUMGUXphngJQweiLW2hwCbUjt16nveD
JA0f3rz//znP83ued16Kfluav0qlSvvv9///c4uCz3ZMtpEKf6d3HxqbMN9G
4UEXz9ccPcPVc789bk+3UfXVbebCtUWcodEUxg/ZqL0v8Xz581Kel2dSTb9g
p1WBDeWa0Ru8/0/nB2fT++lH54WAyzfL+GfTudDcFAf5uTVjWrrK5s/XRT5P
dZLfnLbOxlgTN8dYdY79Lnrdnx31NMREbxakLlu6d4DyTYvKfr1VSTl/7Axp
XzFIzZlf92TYmbwJdfuOdw/SsreOpvWqFgovKvlmyYduWplRG7/ihpUyXkb6
dyx005d7b3ssaU+owmOwNI8OUk9hpL7I+BvdPbXrRfvHg6Q92HYt+5/fyZ7o
dyb6rYuOVowbEuL6qDaoN+DTWCcVGGvur861UXDPyLvYif2UNMF/2qEqB3md
nmF78hv66IvR8agrA1QwY2vtnJhX1Hp3se5RsZuWJv3lvV35kjT67/c9tgxR
UpdHayh5RjmpxbSrbpg6H+aWntZZKSm4ID3iqxHK0eqifym8R44g8yVr5wgN
BEb8tG5Kgdrcb6gO8o5Qljxn5flTeZ+V99VyPp/E+bifN+D+PJmPH2I+P5dv
fo7E/CGyHydjvzrZn5X9X4g+nAd9GkQ/3gr9KkVfVvQ1iP58EPrDH14Df+Af
R8G/k+Iv98Bfu/jPevgPPniqQ/gAPzwGflqFL94Nvg4If1wF/sKFT74eIHwe
Fn559Wvh947wzf7FwrdJ+OeuGcI/8sHlxya5A3vNauSDs2f6npPy/nZ5n5AP
PiXnE/LBf8v9pMzX5fLNRxbMXyvzUxX2c4b69qMm7B/m9O3PyAerRR9W9CsX
/dgDfXeIvqzo/4noz0fgD4k/bIZ/HeIf/wB/kQ/uhf8nxH9uBR/fCR8cBn4S
hB+2Sz54pfDFyAdbhD+OAZ/rhU/eCH6RD74HvpOFb94E/p3CPyeU7dnsjWus
Rz44FPlx4Xn7+/niaOTPiPOjkM843J+D/D7CfN3I92eYfzbyr8V+TegHI/bv
Rn/kQ5/r6BcD9KtB/7RA30z0UyL0X4j+mgR/xtFvavhnRP+Nw99X6MesfPH/
AfpTL/ngCvSrNUT4aUP/LgdfOvTzkgHhLwL9HS/9TZno9y3S71SD/p8l/U/K
92GqfB9I+X5IPhrr/wXgaIMx
      "]]}, {{}, {}}}},
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-1.0100757741834467`, 1.0100757741834465`}, {-1.2488, 1.2488}},
  
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.889440151464692*^9, 3.8894417541373787`*^9, 
  3.889441792620688*^9, 3.889462694049279*^9, 3.889462764303812*^9, 
  3.891017382163652*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"adbaa40b-b339-41c7-a090-c8ac78e8e1b5"]
}, Open  ]],

Cell["\<\
Show the final plot complete with circular arc from 14\[Degree] to 166\
\[Degree] (i.e. 76\[Degree] amplitude) complete with labels and annotation.  \
This is Fig.9.35.  (Note that the diagram in the book is incorrect because it \
shows an amplitude of libration that is only half of the known value.)\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.889462510491029*^9, 3.889462530321175*^9}, {
  3.889462573282261*^9, 3.8894626811481867`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e4205b70-48f1-4d39-8368-c285d6f1faac"],

Cell[BoxData[
 RowBox[{"basic2", "=", "\[IndentingNewLine]", 
  RowBox[{"Rotate", "[", 
   RowBox[{
    RowBox[{"Show", "[", 
     RowBox[{"basic", ",", " ", "\n", "  ", 
      RowBox[{"Graphics", "[", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Disk", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", "0.1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"Dashed", ",", 
           RowBox[{"Line", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", "0"}], "}"}], ",", 
              RowBox[{"0.7616", "*", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"14", " ", "Degree"}], "]"}], ",", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"14", " ", "Degree"}], "]"}]}], "}"}]}]}], "}"}], 
            "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"Dashed", ",", 
           RowBox[{"Line", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", "0"}], "}"}], ",", 
              RowBox[{"0.7616", "*", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"166", " ", "Degree"}], "]"}], ",", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"166", " ", "Degree"}], "]"}]}], "}"}]}]}], "}"}], 
            "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Thickness", "[", "0.005", "]"}], ",", 
         RowBox[{"Arrowheads", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.05"}], ",", "0.05"}], "}"}], "]"}], ",", 
         RowBox[{"Arrow", "[", 
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", "0.7616", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"14", " ", "Degree"}], ",", " ", 
              RowBox[{"166", " ", "Degree"}]}], "}"}]}], "]"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Thickness", "[", "0.002", "]"}], ",", 
         RowBox[{"Circle", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", "0.2", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"14", " ", "Degree"}], ",", " ", 
             RowBox[{"166", " ", "Degree"}]}], "}"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
           RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
           RowBox[{"Text", "[", 
            RowBox[{"\"\<Sun\>\"", ",", 
             RowBox[{"{", 
              RowBox[{"0.1", ",", 
               RowBox[{"-", "0.1"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
           RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
           RowBox[{"Text", "[", 
            RowBox[{"\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
SuperscriptBox[\"152\", \"\[EmptySmallCircle]\"], TraditionalForm], \
\"errors\" -> {}, \"input\" -> \"152^\\\\circ\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\"", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "0.05"}], ",", "0.3"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
           RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
           RowBox[{"Text", "[", 
            RowBox[{"\"\<P\>\"", ",", 
             RowBox[{"{", 
              RowBox[{"0.8", ",", "1"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
           RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
           RowBox[{"Text", "[", 
            RowBox[{"\"\<N\>\"", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "0.35"}], ",", "0.78"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], "}"}]}], "}"}], 
       "]"}]}], "]"}], ",", 
    RowBox[{"\[Pi]", "/", "2"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8894435134975977`*^9, 3.889443514336454*^9}, {
  3.889443565557828*^9, 3.88944361083302*^9}, {3.889444064046739*^9, 
  3.889444071426956*^9}, {3.889462559152987*^9, 3.8894625595578403`*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"cc71d914-59fb-4690-b6c7-6ebb044b5bd0"],

Cell[BoxData[
 RotationBox[
  GraphicsBox[{{{{}, {{}, {}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.009166666666666668], AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxVl3lU1HUUxUGtcCH1uCRYmU4qGrge0hJ8IibmvuQCJoJg4lIkqAmWaG4E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         "]]}}, {{}, {}}}, {{}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
       AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVlWtMk3cUxgtx8QJGE0UBE5mghqhM3UJwWjzzEkviBVEBa6aZCFl1Mw0W
MYMl6vbFgMVYFOIHb0ERRLlYESaEMyUMGUXphngJQweiLW2hwCbUjt16nveD
JA0f3rz//znP83ued16Kfluav0qlSvvv9///c4uCz3ZMtpEKf6d3HxqbMN9G
4UEXz9ccPcPVc789bk+3UfXVbebCtUWcodEUxg/ZqL0v8Xz581Kel2dSTb9g
p1WBDeWa0Ru8/0/nB2fT++lH54WAyzfL+GfTudDcFAf5uTVjWrrK5s/XRT5P
dZLfnLbOxlgTN8dYdY79Lnrdnx31NMREbxakLlu6d4DyTYvKfr1VSTl/7Axp
XzFIzZlf92TYmbwJdfuOdw/SsreOpvWqFgovKvlmyYduWplRG7/ihpUyXkb6
dyx005d7b3ssaU+owmOwNI8OUk9hpL7I+BvdPbXrRfvHg6Q92HYt+5/fyZ7o
dyb6rYuOVowbEuL6qDaoN+DTWCcVGGvur861UXDPyLvYif2UNMF/2qEqB3md
nmF78hv66IvR8agrA1QwY2vtnJhX1Hp3se5RsZuWJv3lvV35kjT67/c9tgxR
UpdHayh5RjmpxbSrbpg6H+aWntZZKSm4ID3iqxHK0eqifym8R44g8yVr5wgN
BEb8tG5Kgdrcb6gO8o5Qljxn5flTeZ+V99VyPp/E+bifN+D+PJmPH2I+P5dv
fo7E/CGyHydjvzrZn5X9X4g+nAd9GkQ/3gr9KkVfVvQ1iP58EPrDH14Df+Af
R8G/k+Iv98Bfu/jPevgPPniqQ/gAPzwGflqFL94Nvg4If1wF/sKFT74eIHwe
Fn559Wvh947wzf7FwrdJ+OeuGcI/8sHlxya5A3vNauSDs2f6npPy/nZ5n5AP
PiXnE/LBf8v9pMzX5fLNRxbMXyvzUxX2c4b69qMm7B/m9O3PyAerRR9W9CsX
/dgDfXeIvqzo/4noz0fgD4k/bIZ/HeIf/wB/kQ/uhf8nxH9uBR/fCR8cBn4S
hB+2Sz54pfDFyAdbhD+OAZ/rhU/eCH6RD74HvpOFb94E/p3CPyeU7dnsjWus
Rz44FPlx4Xn7+/niaOTPiPOjkM843J+D/D7CfN3I92eYfzbyr8V+TegHI/bv
Rn/kQ5/r6BcD9KtB/7RA30z0UyL0X4j+mgR/xtFvavhnRP+Nw99X6MesfPH/
AfpTL/ngCvSrNUT4aUP/LgdfOvTzkgHhLwL9HS/9TZno9y3S71SD/p8l/U/K
92GqfB9I+X5IPhrr/wXgaIMx
        "]]}, {{}, {}}}}, {DiskBox[{0, 0}, 0.1], 
     {Dashing[{Small, Small}], 
      LineBox[{{0, 0}, {0.738977225131799, 0.18424771568870696`}}]}, 
     {Dashing[{Small, Small}], 
      LineBox[{{0, 0}, {-0.738977225131799, 0.18424771568870696`}}]}, 
     {Thickness[0.005], Arrowheads[{-0.05, 0.05}], 
      ArrowBox[CircleBox[{0, 0}, 0.7616, 
        NCache[{14 Degree, 166 Degree}, {0.24434609527920614`, 
         2.897246558310587}]]], 
      {Thickness[0.002], 
       CircleBox[{0, 0}, 0.2, 
        NCache[{14 Degree, 166 Degree}, {0.24434609527920614`, 
         2.897246558310587}]], 
       StyleBox[
        InsetBox["\<\"Sun\"\>", {0.1, -0.1}, NCache[
         ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]], 
         Automatic, {0, -1}],
        FontFamily->"Times",
        FontSize->16], 
       StyleBox[
        InsetBox["\<\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[SuperscriptBox[\\\"152\\\", \\\"\[EmptySmallCircle]\\\"], \
TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"152^\\\\\\\\circ\
\\\", \\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"\>", \
{-0.05, 0.3}, NCache[ImageScaled[{Rational[1, 2], 0}], ImageScaled[{0.5, 0}]],
          Automatic, {0, -1}],
        FontFamily->"Times",
        FontSize->16], 
       StyleBox[
        InsetBox["\<\"P\"\>", {0.8, 1}, NCache[
         ImageScaled[{Rational[1, 2], 0}], ImageScaled[{0.5, 0}]], 
         Automatic, {0, -1}],
        FontFamily->"Times",
        FontSize->16], 
       StyleBox[
        InsetBox["\<\"N\"\>", {-0.35, 0.78}, NCache[
         ImageScaled[{Rational[1, 2], 0}], ImageScaled[{0.5, 0}]], 
         Automatic, {0, -1}],
        FontFamily->"Times",
        FontSize->16]}}}},
   Axes->{False, False},
   AxesLabel->{None, None},
   AxesOrigin->{0, 0},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   Method->{
    "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
     "DefaultGraphicsInteraction" -> {
      "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
       "Effects" -> {
        "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
         "Droplines" -> {
          "freeformCursorMode" -> True, 
           "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
     "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
       Directive[
        RGBColor[0.368417, 0.506779, 0.709798], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.880722, 0.611041, 0.142051], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.560181, 0.691569, 0.194885], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.922526, 0.385626, 0.209179], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.528488, 0.470624, 0.701351], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.772079, 0.431554, 0.102387], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.363898, 0.618501, 0.782349], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[1, 0.75, 0], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.647624, 0.37816, 0.614037], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.571589, 0.586483, 0.], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.915, 0.3325, 0.2125], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
        
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
        AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
     "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
     "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         Identity[
          Part[#, 1]], 
         Identity[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Identity[
          Part[#, 1]], 
         Identity[
          Part[#, 2]]}& )}},
   PlotRange->{{-1.0100757741834467`, 1.0100757741834465`}, {-1.2488, 1.2488}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {
      Scaled[0.05], 
      Scaled[0.05]}},
   Ticks->{Automatic, Automatic}],
  BoxRotation->1.5707963267948966`]], "Output",
 CellChangeTimes->{
  3.889443640501577*^9, {3.889444067492508*^9, 3.889444072879774*^9}, 
   3.889462694098235*^9, 3.8894627643250504`*^9, 3.8910173822478724`*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"a23d695b-a3c6-4751-b782-3cf08354e63a"]
},
WindowToolbars->"MultipurposeBar",
CellGrouping->Manual,
WindowSize->{1052, 674},
WindowMargins->{{79, Automatic}, {Automatic, 24}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"53afbaf2-c264-4dc6-8d1d-043fc57a11cb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 439, 9, 53, "Text",ExpressionUUID->"b05a49bb-672b-4e08-bf6c-4aa2718cba0d"],
Cell[1000, 31, 109, 0, 67, "Section",ExpressionUUID->"0cb2454b-441b-4009-ba28-e4a0e17b409a"],
Cell[1112, 33, 338, 9, 49, "Text",ExpressionUUID->"40d5ca2b-c629-4b78-a3ed-63e435c2e1fd"],
Cell[1453, 44, 232, 6, 53, "Text",ExpressionUUID->"8160fe4d-b57a-47e3-95f2-b43828d07d73"],
Cell[1688, 52, 623, 17, 30, "Input",ExpressionUUID->"644d4524-6566-4ab3-afda-e28fb3c69d79"],
Cell[2314, 71, 387, 9, 53, "Text",ExpressionUUID->"eae70547-4385-46fb-833d-2a11a349b9db"],
Cell[2704, 82, 551, 14, 30, "Input",ExpressionUUID->"0e268aeb-cee9-4606-b4c0-5b42419b815d"],
Cell[3258, 98, 369, 13, 53, "Text",ExpressionUUID->"d30a51c2-eccf-41f1-9b89-f4d92bc8aa87"],
Cell[3630, 113, 1004, 29, 52, "Input",ExpressionUUID->"2589c640-3b19-4c90-b800-909f8d6e77ff"],
Cell[4637, 144, 218, 7, 53, "Text",ExpressionUUID->"32930df0-f043-41bf-8bbf-bc799e8987d3"],
Cell[4858, 153, 238, 5, 30, "Input",ExpressionUUID->"92e26b0a-de9f-4d4a-a051-03be73155876"],
Cell[5099, 160, 222, 6, 53, "Text",ExpressionUUID->"c75a3481-4524-4761-b2ac-3ae27b47cd8c"],
Cell[5324, 168, 320, 7, 30, "Input",ExpressionUUID->"76b66bad-ed3b-47c0-928b-697d83a92631"],
Cell[5647, 177, 175, 3, 53, "Text",ExpressionUUID->"38c9d84c-d097-46f1-91d8-54b0f37f2041"],
Cell[5825, 182, 1699, 47, 178, "Input",ExpressionUUID->"09a11beb-f2e6-40a3-b80b-408b892224da"],
Cell[7527, 231, 176, 3, 53, "Text",ExpressionUUID->"de72363e-dbf8-40a3-a918-8e3024779d8e"],
Cell[CellGroupData[{
Cell[7728, 238, 417, 9, 30, "Input",ExpressionUUID->"ec2fd0c9-b23f-440f-99df-f0a4bd569f79"],
Cell[8148, 249, 5958, 134, 449, "Output",ExpressionUUID->"6905be7b-6df0-4d31-b903-0fcef784d6c9"]
}, Open  ]],
Cell[14121, 386, 326, 8, 53, "Text",ExpressionUUID->"7cee5d2c-70e4-4cfe-b18f-47bd230f3fb5"],
Cell[CellGroupData[{
Cell[14472, 398, 636, 16, 30, "Input",ExpressionUUID->"7ce62d0c-660b-4804-aeac-de83fe5ad097"],
Cell[15111, 416, 4961, 118, 449, "Output",ExpressionUUID->"cb762470-78ea-4307-a0d1-2619f55c4899"]
}, Open  ]],
Cell[20087, 537, 151, 3, 53, "Text",ExpressionUUID->"29eaf0ba-9c9e-4b23-9c1a-da2f0185d3cd"],
Cell[CellGroupData[{
Cell[20263, 544, 256, 5, 30, "Input",ExpressionUUID->"7656016e-091c-4f12-84a2-322ebe166d2a"],
Cell[20522, 551, 7417, 159, 449, "Output",ExpressionUUID->"adbaa40b-b339-41c7-a090-c8ac78e8e1b5"]
}, Open  ]],
Cell[27954, 713, 552, 10, 76, "Text",ExpressionUUID->"e4205b70-48f1-4d39-8368-c285d6f1faac"],
Cell[28509, 725, 5647, 139, 272, "Input",ExpressionUUID->"cc71d914-59fb-4690-b6c7-6ebb044b5bd0"],
Cell[34159, 866, 9283, 200, 347, "Output",ExpressionUUID->"a23d695b-a3c6-4751-b782-3cf08354e63a"]
}
]
*)

